==> aad_fastapi-1.0.3.tar.gz: aad_fastapi-1.0.3/HISTORY.md <==
Changelog
=========


(unreleased)
------------
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Merge branch 'master' of https://github.com/Mimetis/aad_fastapi. [Dor
  Lugasi-Gal]
- Update release.yml. [Dor Lugasi-Gal]
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Upload to codecov only once. [Dor Lugasi-Gal]
- Trigger on master andadd versions to python version matrix. [Dor
  Lugasi-Gal]
- Merge pull request #3 from Mimetis/dorlu/restructure-code. [Sébastien
  Pertus]

  New Structure for code
- Very basic dev container. [Dor Lugasi-Gal]
- Update VERSION. [Dor Lugasi-Gal]
- Update CONTRIBUTING.md. [Dor Lugasi-Gal]
- Update HISTORY.md. [Dor Lugasi-Gal]
- Update FUNDING.yml. [Dor Lugasi-Gal]
- Adding dev container and vscode configuration again. [Dor Lugasi-Gal]
- New structure. [Dor Lugasi-Gal]
- Merge pull request #2 from Mimetis/dorlu/feature/remove-redundant-
  backend-logic. [Dor Lugasi-Gal]

  🔥 remove redundant backend logic
- Update sample/api/main.py. [Dor Lugasi-Gal, Sharon Hart]
- Update tests/test_oauth2_scheme.py. [Dor Lugasi-Gal, Sharon Hart]
- Modified sample readme. [Dor Lugasi-Gal]
- Merge remote-tracking branch 'origin/dorlu/feature/remove-redundant-
  backend-logic' into dorlu/feature/remove-redundant-backend-logic. [Dor
  Lugasi-Gal]
- Update main.py. [Dor Lugasi-Gal]
- Fixed source root. [Dor Lugasi-Gal]
- :fire: removed redundant aad_client and its dependencies and usages.
  [Dor Lugasi-Gal]
- :fire: removed redundant aad_client and its dependencies and usages.
  [Dor Lugasi-Gal]
- Merge remote-tracking branch 'origin/master' [Dor Lugasi-Gal]

  # Conflicts:
  #	src/pyproject.toml
- Update pyproject.toml. [Dor Lugasi-Gal]
- Update pyproject.toml. [Dor Lugasi-Gal]
- Update pyproj. [Dor Lugasi-Gal]
- Fix readme location. [Dor Lugasi-Gal]
- Merge pull request #1 from dorlugasigal/dorlu/fix/packaging-moved-to-
  pyproject-toml. [Sébastien Pertus]

  fixed packaging and set version to 1.0.0
- Update aad_token.py. [Dor Lugasi-Gal]
- Fixed aad_token file. [Dor Lugasi-Gal]
- Fixed folder structure again. [Dor Lugasi-Gal]
- Fixed and bumped version to 1.0.0. [Dor Lugasi-Gal]
- Change to aad_fastapi. [Sebastien Pertus]
- Change to aad_fastapi. [Sebastien Pertus]
- Completing readme.md file. [Sebastien Pertus]
- Add readme file. [Sebastien Pertus]
- Fixes. [Sebastien Pertus]
- Add clean flask session. [Sebastien Pertus]
- Fix secret. [Sebastien Pertus]
- Fix issues depending on two app registrations. [Sebastien Pertus]
- Inprogress. [Sebastien Pertus]
- Add launch.json. [Sebastien Pertus]
- Correct ssh path. [Sebastien Pertus]
- Add first commit. [Sebastien Pertus]

==> aad_fastapi-1.0.5.tar.gz: aad_fastapi-1.0.5/HISTORY.md <==
Changelog
=========


(unreleased)
------------
- Merge pull request #6 from Mimetis/dorlu/fix/pipe-options-to-bearer-
  backend. [Dor Lugasi-Gal]

  pipe options from bearer backend to ensure_user_from_token
- Removed cache manager. [Dor Lugasi-Gal]
- Merge remote-tracking branch 'origin/master' into dorlu/fix/pipe-
  options-to-bearer-backend. [Dor Lugasi-Gal]

  # Conflicts:
  #	aad_fastapi/aad_cache_manager.py
- Formatting. [Dor Lugasi-Gal]
- Pipe options from bearer backend to ensure_user_from_token. [Dor
  Lugasi-Gal]


1.0.4 (2023-03-13)
------------------
- Release: version 1.0.4 🚀 [root]
- Release: version ${TAG} ≡ƒÜÇ. [Dor Lugasi]
- Merge pull request #4 from Mimetis/dorlu/fix/remove-redundant-code.
  [Dor Lugasi-Gal]

  Dorlu/fix/remove redundant code
- Dont need reach. [Dor Lugasi-Gal]
- Small change to check PR comment. [Dor Lugasi-Gal]
- Codecov.yml file (to show report on the PR as a comment) [Dor Lugasi-
  Gal]
- Codecov.yml file (to show report on the PR as a comment) [Dor Lugasi-
  Gal]
- Lint. [Dor Lugasi-Gal]
- Readme changes. [Dor Lugasi-Gal]
- Minor code changes and remove redundant cache manager and certificate
  files. [Dor Lugasi-Gal]


1.0.3 (2023-03-08)
------------------
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Merge branch 'master' of https://github.com/Mimetis/aad_fastapi. [Dor
  Lugasi-Gal]
- Update release.yml. [Dor Lugasi-Gal]
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Release: version 1.0.3 🚀 [Dor Lugasi-Gal]
- Upload to codecov only once. [Dor Lugasi-Gal]
- Trigger on master andadd versions to python version matrix. [Dor
  Lugasi-Gal]
- Merge pull request #3 from Mimetis/dorlu/restructure-code. [Sébastien
  Pertus]

  New Structure for code
- Very basic dev container. [Dor Lugasi-Gal]
- Update VERSION. [Dor Lugasi-Gal]
- Update CONTRIBUTING.md. [Dor Lugasi-Gal]
- Update HISTORY.md. [Dor Lugasi-Gal]
- Update FUNDING.yml. [Dor Lugasi-Gal]
- Adding dev container and vscode configuration again. [Dor Lugasi-Gal]
- New structure. [Dor Lugasi-Gal]
- Merge pull request #2 from Mimetis/dorlu/feature/remove-redundant-
  backend-logic. [Dor Lugasi-Gal]

  🔥 remove redundant backend logic
- Update sample/api/main.py. [Dor Lugasi-Gal, Sharon Hart]
- Update tests/test_oauth2_scheme.py. [Dor Lugasi-Gal, Sharon Hart]
- Modified sample readme. [Dor Lugasi-Gal]
- Merge remote-tracking branch 'origin/dorlu/feature/remove-redundant-
  backend-logic' into dorlu/feature/remove-redundant-backend-logic. [Dor
  Lugasi-Gal]
- Update main.py. [Dor Lugasi-Gal]
- Fixed source root. [Dor Lugasi-Gal]
- :fire: removed redundant aad_client and its dependencies and usages.
  [Dor Lugasi-Gal]
- :fire: removed redundant aad_client and its dependencies and usages.
  [Dor Lugasi-Gal]
- Merge remote-tracking branch 'origin/master' [Dor Lugasi-Gal]

  # Conflicts:
  #	src/pyproject.toml
- Update pyproject.toml. [Dor Lugasi-Gal]
- Update pyproject.toml. [Dor Lugasi-Gal]
- Update pyproj. [Dor Lugasi-Gal]
- Fix readme location. [Dor Lugasi-Gal]
- Merge pull request #1 from dorlugasigal/dorlu/fix/packaging-moved-to-
  pyproject-toml. [Sébastien Pertus]

  fixed packaging and set version to 1.0.0
- Update aad_token.py. [Dor Lugasi-Gal]
- Fixed aad_token file. [Dor Lugasi-Gal]
- Fixed folder structure again. [Dor Lugasi-Gal]
- Fixed and bumped version to 1.0.0. [Dor Lugasi-Gal]
- Change to aad_fastapi. [Sebastien Pertus]
- Change to aad_fastapi. [Sebastien Pertus]
- Completing readme.md file. [Sebastien Pertus]
- Add readme file. [Sebastien Pertus]
- Fixes. [Sebastien Pertus]
- Add clean flask session. [Sebastien Pertus]
- Fix secret. [Sebastien Pertus]
- Fix issues depending on two app registrations. [Sebastien Pertus]
- Inprogress. [Sebastien Pertus]
- Add launch.json. [Sebastien Pertus]
- Correct ssh path. [Sebastien Pertus]
- Add first commit. [Sebastien Pertus]
